fnss.netconfig.capacities.set_capacities_pagerank_gravity — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »

# fnss.netconfig.capacities.set_capacities_pagerank_gravity

`set_capacities_pagerank_gravity`(topology, capacities, capacity_unit='Mbps', alpha=0.85, weight=None)

  Set link capacities proportionally to the product of the Pagerank centralities of the two end-points of the link

  Parameters : | topology : Topology The topology to which link capacities will be set capacities : list A list of all possible capacity values capacity_unit : str, optional The unit in which capacity value is expressed (e.g. Mbps, Gbps etc..) alpha : float, optional The apha parameter of the PageRank algorithm weight : str, optional The name of the link attribute to use for the PageRank algorithm. Valid attributes include capacity delay and weight. If `None`, all links are assigned the same weight.

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »